@@ -283,6 +283,10 @@ pub trait PyNumberProtocol<'p>: PyClass {
     {
         unimplemented!()
     }
+    #[deprecated(
+        since = "0.14.0",
+        note = "prefer implementing `__complex__` in `#[pymethods]` instead of in a protocol"
+    )]
     fn __complex__(&'p self) -> Self::Result
     where
         Self: PyNumberComplexProtocol<'p>,
@@ -307,6 +311,10 @@ pub trait PyNumberProtocol<'p>: PyClass {
     {
         unimplemented!()
     }
+    #[deprecated(
+        since = "0.14.0",
+        note = "prefer implementing `__round__` in `#[pymethods]` instead of in a protocol"
+    )]
     fn __round__(&'p self, ndigits: Option<Self::NDigits>) -> Self::Result
     where
         Self: PyNumberRoundProtocol<'p>,
@@ -446,11 +454,13 @@ pub trait PyNumberRPowProtocol<'p>: PyNumberProtocol<'p> {
     type Result: IntoPyCallbackOutput<PyObject>;
 }
 
+#[allow(clippy::upper_case_acronyms)]
 pub trait PyNumberRLShiftProtocol<'p>: PyNumberProtocol<'p> {
     type Other: FromPyObject<'p>;
     type Result: IntoPyCallbackOutput<PyObject>;
 }
 
+#[allow(clippy::upper_case_acronyms)]
 pub trait PyNumberRRShiftProtocol<'p>: PyNumberProtocol<'p> {
     type Other: FromPyObject<'p>;
     type Result: IntoPyCallbackOutput<PyObject>;
@@ -516,11 +526,13 @@ pub trait PyNumberIPowProtocol<'p>: PyNumberProtocol<'p> {
     type Result: IntoPyCallbackOutput<()>;
 }
 
+#[allow(clippy::upper_case_acronyms)]
 pub trait PyNumberILShiftProtocol<'p>: PyNumberProtocol<'p> {
     type Other: FromPyObject<'p>;
     type Result: IntoPyCallbackOutput<()>;
 }
 
+#[allow(clippy::upper_case_acronyms)]
 pub trait PyNumberIRShiftProtocol<'p>: PyNumberProtocol<'p> {
     type Other: FromPyObject<'p>;
     type Result: IntoPyCallbackOutput<()>;
