@@ -84,7 +84,10 @@ mod tests {
     fn test_non_utf8_conversion() {
         Python::with_gil(|py| {
             use std::ffi::OsStr;
+            #[cfg(not(target_os = "wasi"))]
             use std::os::unix::ffi::OsStrExt;
+            #[cfg(target_os = "wasi")]
+            use std::os::wasi::ffi::OsStrExt;
 
             // this is not valid UTF-8
             let payload = &[250, 251, 252, 253, 254, 255, 0, 255];
