@@ -1,5 +1,3 @@
-#![cfg_attr(feature = "cargo-clippy", allow(clippy::type_complexity))]
-
 //! FFI bindings to the functions and structs defined in `datetime.h`
 //!
 //! This is the unsafe thin  wrapper around the [CPython C API](https://docs.python.org/3/c-api/datetime.html),
@@ -365,14 +363,12 @@ pub struct PyDateTime_CAPI {
     pub TZInfoType: *mut PyTypeObject,
     #[cfg(all(Py_3_7, not(PyPy)))]
     pub TimeZone_UTC: *mut PyObject,
-    #[cfg_attr(PyPy, link_name = "_PyPyDate_FromDate")]
     pub Date_FromDate: unsafe extern "C" fn(
         year: c_int,
         month: c_int,
         day: c_int,
         cls: *mut PyTypeObject,
     ) -> *mut PyObject,
-    #[cfg_attr(PyPy, link_name = "_PyPyDateTime_FromDateAndTime")]
     pub DateTime_FromDateAndTime: unsafe extern "C" fn(
         year: c_int,
         month: c_int,
@@ -384,7 +380,6 @@ pub struct PyDateTime_CAPI {
         tzinfo: *mut PyObject,
         cls: *mut PyTypeObject,
     ) -> *mut PyObject,
-    #[cfg_attr(PyPy, link_name = "_PyPyTime_FromTime")]
     pub Time_FromTime: unsafe extern "C" fn(
         hour: c_int,
         minute: c_int,
@@ -393,7 +388,6 @@ pub struct PyDateTime_CAPI {
         tzinfo: *mut PyObject,
         cls: *mut PyTypeObject,
     ) -> *mut PyObject,
-    #[cfg_attr(PyPy, link_name = "_PyPyDelta_FromDelta")]
     pub Delta_FromDelta: unsafe extern "C" fn(
         days: c_int,
         seconds: c_int,
@@ -405,13 +399,11 @@ pub struct PyDateTime_CAPI {
     pub TimeZone_FromTimeZone:
         unsafe extern "C" fn(offset: *mut PyObject, name: *mut PyObject) -> *mut PyObject,
 
-    // Defined for PyPy as `PyDateTime_FromTimestamp`
     pub DateTime_FromTimestamp: unsafe extern "C" fn(
         cls: *mut PyTypeObject,
         args: *mut PyObject,
         kwargs: *mut PyObject,
     ) -> *mut PyObject,
-    // Defined for PyPy as `PyDate_FromTimestamp`
     pub Date_FromTimestamp:
         unsafe extern "C" fn(cls: *mut PyTypeObject, args: *mut PyObject) -> *mut PyObject,
     #[cfg(not(PyPy))]
@@ -441,26 +433,29 @@ pub struct PyDateTime_CAPI {
 
 // Python already shares this object between threads, so it's no more evil for us to do it too!
 unsafe impl Sync for PyDateTime_CAPI {}
-static PY_DATETIME_API: GILOnceCell<&'static PyDateTime_CAPI> = GILOnceCell::new();
 
-#[derive(Debug)]
-pub struct PyDateTimeAPI {
-    __private_field: (),
-}
-
-pub static PyDateTimeAPI: PyDateTimeAPI = PyDateTimeAPI {
-    __private_field: (),
+/// Safe wrapper around the Python datetime C-API global. Note that this object differs slightly
+/// from the equivalent C object: in C, this is implemented as a `static PyDateTime_CAPI *`. Here
+/// this is implemented as a wrapper which implements [`Deref`] to access a reference to a
+/// [`PyDateTime_CAPI`] object.
+///
+/// In the [`Deref`] implementation, if the underlying object has not yet been initialized, the GIL
+/// will automatically be acquired and [`PyDateTime_IMPORT()`] called.
+pub static PyDateTimeAPI: _PyDateTimeAPI_impl = _PyDateTimeAPI_impl {
+    inner: GILOnceCell::new(),
 };
 
-impl Deref for PyDateTimeAPI {
-    type Target = PyDateTime_CAPI;
+/// Safe wrapper around the Python C-API global `PyDateTime_TimeZone_UTC`. This follows a similar
+/// strategy as [`PyDateTimeAPI`]: the Python datetime C-API will automatically be imported if this
+/// type is deferenced.
+///
+/// The type obtained by dereferencing this object is `&'static PyObject`. This may change in the
+/// future to be a more specific type representing that this is a `datetime.timezone` object.
+#[cfg(all(Py_3_7, not(PyPy)))]
+pub static PyDateTime_TimeZone_UTC: _PyDateTime_TimeZone_UTC_impl = _PyDateTime_TimeZone_UTC_impl {
+    inner: &PyDateTimeAPI,
+};
 
-    fn deref(&self) -> &'static PyDateTime_CAPI {
-        unsafe { PyDateTime_IMPORT() }
-    }
-}
-
-#[inline]
 /// Populates the `PyDateTimeAPI` object
 ///
 /// Unlike in C, this does *not* need to be actively invoked in Rust, which
@@ -472,23 +467,29 @@ impl Deref for PyDateTimeAPI {
 /// # Safety
 /// The Python GIL must be held.
 pub unsafe fn PyDateTime_IMPORT() -> &'static PyDateTime_CAPI {
-    let py = Python::assume_gil_acquired();
-    PY_DATETIME_API.get_or_init(py, || {
-        // PyPy expects the C-API to be initialized via PyDateTime_Import, so trying to use
-        // `PyCapsule_Import` will behave unexpectedly in pypy.
-        #[cfg(PyPy)]
-        let py_datetime_c_api = PyDateTime_Import();
+    PyDateTimeAPI
+        .inner
+        .get_or_init(Python::assume_gil_acquired(), || {
+            // Because `get_or_init` is called with `assume_gil_acquired()`, it's necessary to acquire
+            // the GIL here to prevent segfault in usage of the safe `PyDateTimeAPI::deref` impl.
+            Python::with_gil(|_py| {
+                // PyPy expects the C-API to be initialized via PyDateTime_Import, so trying to use
+                // `PyCapsule_Import` will behave unexpectedly in pypy.
+                #[cfg(PyPy)]
+                let py_datetime_c_api = PyDateTime_Import();
 
-        #[cfg(not(PyPy))]
-        let py_datetime_c_api = {
-            // PyDateTime_CAPSULE_NAME is a macro in C
-            let PyDateTime_CAPSULE_NAME = CString::new("datetime.datetime_CAPI").unwrap();
+                #[cfg(not(PyPy))]
+                let py_datetime_c_api = {
+                    // PyDateTime_CAPSULE_NAME is a macro in C
+                    let PyDateTime_CAPSULE_NAME = CString::new("datetime.datetime_CAPI").unwrap();
 
-            &*(PyCapsule_Import(PyDateTime_CAPSULE_NAME.as_ptr(), 1) as *const PyDateTime_CAPI)
-        };
+                    &*(PyCapsule_Import(PyDateTime_CAPSULE_NAME.as_ptr(), 1)
+                        as *const PyDateTime_CAPI)
+                };
 
-        py_datetime_c_api
-    })
+                py_datetime_c_api
+            })
+        })
 }
 
 // skipped non-limited PyDateTime_TimeZone_UTC
@@ -567,6 +568,16 @@ pub unsafe fn PyTZInfo_CheckExact(op: *mut PyObject) -> c_int {
 // skipped non-limited PyTimeZone_FromOffset
 // skipped non-limited PyTimeZone_FromOffsetAndName
 
+#[cfg(not(PyPy))]
+pub unsafe fn PyDateTime_FromTimestamp(args: *mut PyObject) -> *mut PyObject {
+    (PyDateTimeAPI.DateTime_FromTimestamp)(PyDateTimeAPI.DateTimeType, args, std::ptr::null_mut())
+}
+
+#[cfg(not(PyPy))]
+pub unsafe fn PyDate_FromTimestamp(args: *mut PyObject) -> *mut PyObject {
+    (PyDateTimeAPI.Date_FromTimestamp)(PyDateTimeAPI.DateType, args)
+}
+
 #[cfg(PyPy)]
 extern "C" {
     #[link_name = "PyPyDate_FromTimestamp"]
@@ -574,8 +585,91 @@ extern "C" {
     #[link_name = "PyPyDateTime_FromTimestamp"]
     pub fn PyDateTime_FromTimestamp(args: *mut PyObject) -> *mut PyObject;
 }
+
 #[cfg(PyPy)]
 extern "C" {
     #[link_name = "_PyPyDateTime_Import"]
     pub fn PyDateTime_Import() -> &'static PyDateTime_CAPI;
 }
+
+// -- implementation details which are specific to Rust. --
+
+#[doc(hidden)]
+pub struct _PyDateTimeAPI_impl {
+    inner: GILOnceCell<&'static PyDateTime_CAPI>,
+}
+
+impl Deref for _PyDateTimeAPI_impl {
+    type Target = PyDateTime_CAPI;
+
+    #[inline]
+    fn deref(&self) -> &'static PyDateTime_CAPI {
+        unsafe { PyDateTime_IMPORT() }
+    }
+}
+
+#[doc(hidden)]
+#[cfg(all(Py_3_7, not(PyPy)))]
+pub struct _PyDateTime_TimeZone_UTC_impl {
+    inner: &'static _PyDateTimeAPI_impl,
+}
+
+#[cfg(all(Py_3_7, not(PyPy)))]
+impl Deref for _PyDateTime_TimeZone_UTC_impl {
+    type Target = crate::PyObject;
+
+    #[inline]
+    fn deref(&self) -> &crate::PyObject {
+        unsafe {
+            &*((&self.inner.TimeZone_UTC) as *const *mut crate::ffi::PyObject
+                as *const crate::PyObject)
+        }
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::{py_run, AsPyPointer, IntoPy, Py, PyAny, Python};
+
+    #[test]
+    fn test_datetime_fromtimestamp() {
+        Python::with_gil(|py| {
+            let args: Py<PyAny> = (100,).into_py(py);
+            unsafe { PyDateTime_IMPORT() };
+            let dt: &PyAny = unsafe { py.from_owned_ptr(PyDateTime_FromTimestamp(args.as_ptr())) };
+            py_run!(
+                py,
+                dt,
+                "import datetime; assert dt == datetime.datetime.fromtimestamp(100)"
+            );
+        })
+    }
+
+    #[test]
+    fn test_date_fromtimestamp() {
+        Python::with_gil(|py| {
+            let args: Py<PyAny> = (100,).into_py(py);
+            unsafe { PyDateTime_IMPORT() };
+            let dt: &PyAny = unsafe { py.from_owned_ptr(PyDate_FromTimestamp(args.as_ptr())) };
+            py_run!(
+                py,
+                dt,
+                "import datetime; assert dt == datetime.date.fromtimestamp(100)"
+            );
+        })
+    }
+
+    #[test]
+    #[cfg(all(Py_3_7, not(PyPy)))]
+    fn test_utc_timezone() {
+        Python::with_gil(|py| {
+            let utc_timezone = PyDateTime_TimeZone_UTC.as_ref(py);
+            py_run!(
+                py,
+                utc_timezone,
+                "import datetime; assert utc_timezone is datetime.timezone.utc"
+            );
+        })
+    }
+}
