@@ -27,7 +27,7 @@
 //! as the GIL is held, which is why using them doesn't require a  [`Python<'py>`](crate::Python) token.
 //!  The underlying Python object, if mutable, can be mutated through any reference.
 //!
-//! See the [guide](https://pyo3.rs/main/types.html) for an explanation of the different Python object types.
+//! See the [guide](https://pyo3.rs/latest/types.html) for an explanation of the different Python object types.
 //!
 //! ## The GIL-independent types
 //!
@@ -48,7 +48,7 @@
 //!
 //! PyO3 uses [feature flags](https://doc.rust-lang.org/cargo/reference/features.html)
 //! to enable you to opt-in to additional functionality. For a detailed description, see
-//! the [Features Reference chapter of the guide](https://pyo3.rs/main/features.html#features-reference).
+//! the [Features Reference chapter of the guide](https://pyo3.rs/latest/features.html#features-reference).
 //!
 //! ## Default feature flags
 //!
@@ -74,6 +74,10 @@
 //! [`HashMap`](https://docs.rs/hashbrown/latest/hashbrown/struct.HashMap.html) and
 //! [`HashSet`](https://docs.rs/hashbrown/latest/hashbrown/struct.HashSet.html) types.
 //
+//! - [`indexmap`](crate::indexmap): Enables conversions between Python dictionary and
+//! [indexmap](https://docs.rs/indexmap)'s
+//! [`IndexMap`](https://docs.rs/indexmap/latest/indexmap/map/struct.IndexMap.html).
+//
 //! - `multiple-pymethods`: Enables the use of multiple
 //! [`#[pymethods]`](crate::proc_macro::pymethods) blocks per
 //! [`#[pyclass]`](crate::proc_macro::pyclass). This adds a dependency on the
@@ -114,22 +118,19 @@
 //!
 //! # Minimum supported Rust and Python versions
 //!
-//! PyO3 supports Python 3.6+ and Rust 1.41+.
-//!
-//! Building with PyPy is also possible (via cpyext) for Python 3.6,
-//! targeted PyPy version is 7.3+. Please refer to the
-//! [pypy section](https://pyo3.rs/main/building_and_distribution/pypy.html)
-//! in the guide for more information.
+//! PyO3 supports the following software versions:
+//!   - Python 3.6 and up (CPython and PyPy)
+//!   - Rust 1.41 and up
 //!
 //! # Example: Building a native Python module
 //!
-//! To build, test and publish your crate as a Python module, it is recommended that you use
-//! [maturin](https://github.com/PyO3/maturin) or
-//! [setuptools-rust](https://github.com/PyO3/setuptools-rust). You can also do this manually. See the
-//! [Building and Distribution chapter of the guide](https://pyo3.rs/main/building_and_distribution.html)
-//! for more information.
+//! PyO3 can be used to generate a native Python module. The easiest way to try this out for the
+//! first time is to use [`maturin`](https://github.com/PyO3/maturin). `maturin` is a tool for
+//! building and publishing Rust-based Python packages with minimal configuration. The following
+//! steps set up some files for an example Python module, install `maturin`, and then show how build
+//! and import the Python module.
 //!
-//! Add these files to your crate's root:
+//! First, create a new folder (let's call it `string_sum`) containing the following two files:
 //!
 //! **`Cargo.toml`**
 //!
@@ -175,30 +176,46 @@
 //! }
 //! ```
 //!
-//! **`.cargo/config.toml`**
-//! ```toml
-//! # These flags must be passed to rustc when compiling for macOS
-//! # They can be omitted if you pass the flags yourself
-//! # or don't care about macOS
+//! With those two files in place, now `maturin` needs to be installed. This can be done using
+//! Python's package manager `pip`. First, load up a new Python `virtualenv`, and install `maturin`
+//! into it:
 //!
-//! [target.x86_64-apple-darwin]
-//! rustflags = [
-//!   "-C", "link-arg=-undefined",
-//!   "-C", "link-arg=dynamic_lookup",
-//! ]
-//!
-//! [target.aarch64-apple-darwin]
-//! rustflags = [
-//!   "-C", "link-arg=-undefined",
-//!   "-C", "link-arg=dynamic_lookup",
-//! ]
+//! ```bash
+//! $ cd string_sum
+//! $ python -m venv .env
+//! $ source .env/bin/activate
+//! $ pip install maturin
 //! ```
 //!
+//! Now build and execute the module:
+//!
+//! ```bash
+//! $ maturin develop
+//! # lots of progress output as maturin runs the compilation...
+//! $ python
+//! >>> import string_sum
+//! >>> string_sum.sum_as_string(5, 20)
+//! '25'
+//! ```
+//!
+//! As well as with `maturin`, it is possible to build using
+//! [`setuptools-rust`](https://github.com/PyO3/setuptools-rust) or
+//! [manually](https://pyo3.rs/latest/building_and_distribution.html#manual-builds). Both offer more
+//! flexibility than `maturin` but require further configuration.
+//!
 //! # Example: Using Python from Rust
 //!
-//! You can use PyO3 to call Python functions from Rust.
+//! To embed Python into a Rust binary, you need to ensure that your Python installation contains a
+//! shared library. The following steps demonstrate how to ensure this (for Ubuntu), and then give
+//! some example code which runs an embedded Python interpreter.
 //!
-//! Add `pyo3` to your `Cargo.toml`:
+//! To install the Python shared library on Ubuntu:
+//!
+//! ```bash
+//! sudo apt install python3-dev
+//! ```
+//!
+//! Start a new project with `cargo new` and add  `pyo3` to the `Cargo.toml` like this:
 //!
 //! ```toml
 //! [dependencies.pyo3]
@@ -209,26 +226,41 @@
 //! features = ["auto-initialize"]
 //! ```
 //!
-//! Example program displaying the value of `sys.version`:
+//! Example program displaying the value of `sys.version` and the current user name:
 //!
 //! ```rust
 //! use pyo3::prelude::*;
 //! use pyo3::types::IntoPyDict;
 //!
 //! fn main() -> PyResult<()> {
-//!     let gil = Python::acquire_gil();
-//!     let py = gil.python();
-//!     let sys = py.import("sys")?;
-//!     let version: String = sys.get("version")?.extract()?;
+//!     Python::with_gil(|py| {
+//!         let sys = py.import("sys")?;
+//!         let version: String = sys.get("version")?.extract()?;
 //!
-//!     let locals = [("os", py.import("os")?)].into_py_dict(py);
-//!     let code = "os.getenv('USER') or os.getenv('USERNAME') or 'Unknown'";
-//!     let user: String = py.eval(code, None, Some(&locals))?.extract()?;
+//!         let locals = [("os", py.import("os")?)].into_py_dict(py);
+//!         let code = "os.getenv('USER') or os.getenv('USERNAME') or 'Unknown'";
+//!         let user: String = py.eval(code, None, Some(&locals))?.extract()?;
 //!
-//!     println!("Hello {}, I'm Python {}", user, version);
-//!     Ok(())
+//!         println!("Hello {}, I'm Python {}", user, version);
+//!         Ok(())
+//!     })
 //! }
 //! ```
+//!
+//! The guide has [a section](https://pyo3.rs/latest/python_from_rust.html) with lots of examples
+//! about this topic.
+//!
+//! # Other Examples
+//!
+//! The PyO3 [README](https://github.com/PyO3/pyo3#readme) contains quick-start examples for both
+//! using [Rust from Python](https://github.com/PyO3/pyo3#using-rust-from-python) and
+//! [Python from Rust](https://github.com/PyO3/pyo3#using-python-from-rust).
+//!
+//! The PyO3 repository's [examples subdirectory](https://github.com/PyO3/pyo3/tree/main/examples)
+//! contains some basic packages to demonstrate usage of PyO3.
+//!
+//! There are many projects using PyO3 - see a list of some at
+//! <https://github.com/PyO3/pyo3#examples>
 
 pub use crate::class::*;
 pub use crate::conversion::{
@@ -303,6 +335,10 @@ pub mod num_bigint;
 
 pub mod num_complex;
 
+#[cfg_attr(docsrs, doc(cfg(feature = "indexmap")))]
+#[cfg(feature = "indexmap")]
+pub use crate::conversions::indexmap;
+
 #[cfg_attr(docsrs, doc(cfg(feature = "serde")))]
 #[cfg(feature = "serde")]
 pub mod serde;
@@ -487,10 +523,6 @@ pub mod doc_test {
         "guide/src/building_and_distribution.md",
         guide_building_and_distribution_md
     );
-    doctest!(
-        "guide/src/building_and_distribution/pypy.md",
-        guide_building_and_distribution_pypy_md
-    );
     doctest!("guide/src/class.md", guide_class_md);
     doctest!("guide/src/class/protocols.md", guide_class_protocols_md);
     doctest!("guide/src/conversions.md", guide_conversions_md);
@@ -513,4 +545,7 @@ pub mod doc_test {
     doctest!("guide/src/trait_bounds.md", guide_trait_bounds_md);
     doctest!("guide/src/types.md", guide_types_md);
     doctest!("guide/src/faq.md", faq);
+
+    // deliberate choice not to test guide/ecosystem because those pages depend on external crates
+    // such as pyo3_asyncio.
 }
